# coding: utf-8

"""
    IONOS Cloud - DNS API

    Cloud DNS service helps IONOS Cloud customers to automate DNS Zone and Record management.   # noqa: E501

    The version of the OpenAPI document: 1.17.0
    Contact: support@cloud.ionos.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud_dns.configuration import Configuration


class MetadataWithStateNameserversAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'state': 'ProvisioningState',

        'nameservers': 'list[str]',
    }

    attribute_map = {

        'state': 'state',

        'nameservers': 'nameservers',
    }

    def __init__(self, state=None, nameservers=None, local_vars_configuration=None):  # noqa: E501
        """MetadataWithStateNameserversAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._state = None
        self._nameservers = None
        self.discriminator = None

        self.state = state
        self.nameservers = nameservers


    @property
    def state(self):
        """Gets the state of this MetadataWithStateNameserversAllOf.  # noqa: E501


        :return: The state of this MetadataWithStateNameserversAllOf.  # noqa: E501
        :rtype: ProvisioningState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this MetadataWithStateNameserversAllOf.


        :param state: The state of this MetadataWithStateNameserversAllOf.  # noqa: E501
        :type state: ProvisioningState
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def nameservers(self):
        """Gets the nameservers of this MetadataWithStateNameserversAllOf.  # noqa: E501

        The list of nameservers associated to the zone.  Nameservers are different for primary and secondary zones. For primary zones it would be: - ns-ic.ui-dns.com - ns-ic.ui-dns.de - ns-ic.ui-dns.org - ns-ic.ui-dns.biz  And for secondary zones: - nscs.ui-dns.com - nscs.ui-dns.de - nscs.ui-dns.org - nscs.ui-dns.biz   # noqa: E501

        :return: The nameservers of this MetadataWithStateNameserversAllOf.  # noqa: E501
        :rtype: list[str]
        """
        return self._nameservers

    @nameservers.setter
    def nameservers(self, nameservers):
        """Sets the nameservers of this MetadataWithStateNameserversAllOf.

        The list of nameservers associated to the zone.  Nameservers are different for primary and secondary zones. For primary zones it would be: - ns-ic.ui-dns.com - ns-ic.ui-dns.de - ns-ic.ui-dns.org - ns-ic.ui-dns.biz  And for secondary zones: - nscs.ui-dns.com - nscs.ui-dns.de - nscs.ui-dns.org - nscs.ui-dns.biz   # noqa: E501

        :param nameservers: The nameservers of this MetadataWithStateNameserversAllOf.  # noqa: E501
        :type nameservers: list[str]
        """
        if self.local_vars_configuration.client_side_validation and nameservers is None:  # noqa: E501
            raise ValueError("Invalid value for `nameservers`, must not be `None`")  # noqa: E501

        self._nameservers = nameservers
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetadataWithStateNameserversAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MetadataWithStateNameserversAllOf):
            return True

        return self.to_dict() != other.to_dict()
